@@ -14,7 +14,7 @@ use Inline (
         ),
         ($ENV{LIBUSB_INCDIR} ? ( INC => "-I$ENV{LIBUSB_INCDIR}" ) : () ),
         NAME => 'Device::USB',
-        VERSION => '0.22',
+        VERSION => '0.26',
    );
 
 Inline->init();
@@ -45,11 +45,11 @@ Device::USB - Use libusb to access USB devices.
 
 =head1 VERSION
 
-Version 0.22
+Version 0.26
 
 =cut
 
-our $VERSION='0.22';
+our $VERSION='0.26';
 
 
 =head1 SYNOPSIS
@@ -494,13 +494,21 @@ on the module. But thanks mostly go to Paul Archer who proposed the project
 and helped with the development.
 
 Thanks to Josep Monés Teixidor for fixing the C<bInterfaceClass> bug.
+
 Thanks to Mike McCauley for support of C<usb_get_driver_np> and
-C<usb_detach_kernel_driver_np>. Thanks to Vadim Mikhailov for fixing
-a compile problem with VC6 on Windows.
+C<usb_detach_kernel_driver_np>.
+
+Thanks to Vadim Mikhailov for fixing a compile problem with VC6 on Windows.
+
+Thanks to John R. Hogheruis for information about modifying the Inline
+parameters for compiling with Strawberry Perl on Windows.
+
+Thanks to Tony Shadwick for helping me resolve a problem with bulk_read and
+interrupt_read.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006-2007 Houston Perl Mongers
+Copyright 2006-2008 Houston Perl Mongers
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
